@@ -42,6 +42,10 @@ from ..tree import DecisionTreeClassifier, DecisionTreeRegressor
 from ..utils import _safe_indexing, check_random_state
 from ..utils._param_validation import HasMethods, Interval, StrOptions
 from ..utils.extmath import softmax, stable_cumsum
+from ..utils.metadata_routing import (
+    _raise_for_unsupported_routing,
+    _RoutingNotSupportedMixin,
+)
 from ..utils.validation import (
     _check_sample_weight,
     _num_samples,
@@ -68,11 +72,6 @@ class BaseWeightBoosting(BaseEnsemble, metaclass=ABCMeta):
         "n_estimators": [Interval(Integral, 1, None, closed="left")],
         "learning_rate": [Interval(Real, 0, None, closed="neither")],
         "random_state": ["random_state"],
-        "base_estimator": [
-            HasMethods(["fit", "predict"]),
-            StrOptions({"deprecated"}),
-            None,
-        ],
     }
 
     @abstractmethod
@@ -84,13 +83,11 @@ class BaseWeightBoosting(BaseEnsemble, metaclass=ABCMeta):
         estimator_params=tuple(),
         learning_rate=1.0,
         random_state=None,
-        base_estimator="deprecated",
     ):
         super().__init__(
             estimator=estimator,
             n_estimators=n_estimators,
             estimator_params=estimator_params,
-            base_estimator=base_estimator,
         )
 
         self.learning_rate = learning_rate
@@ -132,6 +129,7 @@ class BaseWeightBoosting(BaseEnsemble, metaclass=ABCMeta):
         self : object
             Fitted estimator.
         """
+        _raise_for_unsupported_routing(self, "fit", sample_weight=sample_weight)
         X, y = self._validate_data(
             X,
             y,
@@ -338,16 +336,18 @@ def _samme_proba(estimator, n_classes, X):
     )
 
 
-class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
+class AdaBoostClassifier(
+    _RoutingNotSupportedMixin, ClassifierMixin, BaseWeightBoosting
+):
     """An AdaBoost classifier.
 
-    An AdaBoost [1] classifier is a meta-estimator that begins by fitting a
+    An AdaBoost [1]_ classifier is a meta-estimator that begins by fitting a
     classifier on the original dataset and then fits additional copies of the
     classifier on the same dataset but where the weights of incorrectly
     classified instances are adjusted such that subsequent classifiers focus
     more on difficult cases.
 
-    This class implements the algorithm known as AdaBoost-SAMME [2].
+    This class implements the algorithm based on [2]_.
 
     Read more in the :ref:`User Guide <adaboost>`.
 
@@ -383,6 +383,10 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
         The SAMME.R algorithm typically converges faster than SAMME,
         achieving a lower test error with fewer boosting iterations.
 
+        .. deprecated:: 1.4
+            `"SAMME.R"` is deprecated and will be removed in version 1.6.
+            '"SAMME"' will become the default.
+
     random_state : int, RandomState instance or None, default=None
         Controls the random seed given at each `estimator` at each
         boosting iteration.
@@ -390,17 +394,6 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
         Pass an int for reproducible output across multiple function calls.
         See :term:`Glossary <random_state>`.
 
-    base_estimator : object, default=None
-        The base estimator from which the boosted ensemble is built.
-        Support for sample weighting is required, as well as proper
-        ``classes_`` and ``n_classes_`` attributes. If ``None``, then
-        the base estimator is :class:`~sklearn.tree.DecisionTreeClassifier`
-        initialized with `max_depth=1`.
-
-        .. deprecated:: 1.2
-            `base_estimator` is deprecated and will be removed in 1.4.
-            Use `estimator` instead.
-
     Attributes
     ----------
     estimator_ : estimator
@@ -409,13 +402,6 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
         .. versionadded:: 1.2
            `base_estimator_` was renamed to `estimator_`.
 
-    base_estimator_ : estimator
-        The base estimator from which the ensemble is grown.
-
-        .. deprecated:: 1.2
-            `base_estimator_` is deprecated and will be removed in 1.4.
-            Use `estimator_` instead.
-
     estimators_ : list of classifiers
         The collection of fitted sub-estimators.
 
@@ -474,7 +460,9 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
     .. [1] Y. Freund, R. Schapire, "A Decision-Theoretic Generalization of
            on-Line Learning and an Application to Boosting", 1995.
 
-    .. [2] J. Zhu, H. Zou, S. Rosset, T. Hastie, "Multi-class AdaBoost", 2009.
+    .. [2] :doi:`J. Zhu, H. Zou, S. Rosset, T. Hastie, "Multi-class adaboost."
+           Statistics and its Interface 2.3 (2009): 349-360.
+           <10.4310/SII.2009.v2.n3.a8>`
 
     Examples
     --------
@@ -483,20 +471,33 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
     >>> X, y = make_classification(n_samples=1000, n_features=4,
     ...                            n_informative=2, n_redundant=0,
     ...                            random_state=0, shuffle=False)
-    >>> clf = AdaBoostClassifier(n_estimators=100, random_state=0)
+    >>> clf = AdaBoostClassifier(n_estimators=100, algorithm="SAMME", random_state=0)
     >>> clf.fit(X, y)
-    AdaBoostClassifier(n_estimators=100, random_state=0)
+    AdaBoostClassifier(algorithm='SAMME', n_estimators=100, random_state=0)
     >>> clf.predict([[0, 0, 0, 0]])
     array([1])
     >>> clf.score(X, y)
-    0.983...
+    0.96...
+
+    For a detailed example of using AdaBoost to fit a sequence of DecisionTrees
+    as weaklearners, please refer to
+    :ref:`sphx_glr_auto_examples_ensemble_plot_adaboost_multiclass.py`.
+
+    For a detailed example of using AdaBoost to fit a non-linearly seperable
+    classification dataset composed of two Gaussian quantiles clusters, please
+    refer to :ref:`sphx_glr_auto_examples_ensemble_plot_adaboost_twoclass.py`.
     """
 
+    # TODO(1.6): Modify _parameter_constraints for "algorithm" to only check
+    # for "SAMME"
     _parameter_constraints: dict = {
         **BaseWeightBoosting._parameter_constraints,
-        "algorithm": [StrOptions({"SAMME", "SAMME.R"})],
+        "algorithm": [
+            StrOptions({"SAMME", "SAMME.R"}),
+        ],
     }
 
+    # TODO(1.6): Change default "algorithm" value to "SAMME"
     def __init__(
         self,
         estimator=None,
@@ -505,14 +506,12 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
         learning_rate=1.0,
         algorithm="SAMME.R",
         random_state=None,
-        base_estimator="deprecated",
     ):
         super().__init__(
             estimator=estimator,
             n_estimators=n_estimators,
             learning_rate=learning_rate,
             random_state=random_state,
-            base_estimator=base_estimator,
         )
 
         self.algorithm = algorithm
@@ -521,8 +520,18 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
         """Check the estimator and set the estimator_ attribute."""
         super()._validate_estimator(default=DecisionTreeClassifier(max_depth=1))
 
-        #  SAMME-R requires predict_proba-enabled base estimators
-        if self.algorithm == "SAMME.R":
+        # TODO(1.6): Remove, as "SAMME.R" value for "algorithm" param will be
+        # removed in 1.6
+        # SAMME-R requires predict_proba-enabled base estimators
+        if self.algorithm != "SAMME":
+            warnings.warn(
+                (
+                    "The SAMME.R algorithm (the default) is deprecated and will be"
+                    " removed in 1.6. Use the SAMME algorithm to circumvent this"
+                    " warning."
+                ),
+                FutureWarning,
+            )
             if not hasattr(self.estimator_, "predict_proba"):
                 raise TypeError(
                     "AdaBoostClassifier with algorithm='SAMME.R' requires "
@@ -531,11 +540,17 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
                     "Please change the base estimator or set "
                     "algorithm='SAMME' instead."
                 )
+
         if not has_fit_parameter(self.estimator_, "sample_weight"):
             raise ValueError(
                 f"{self.estimator.__class__.__name__} doesn't support sample_weight."
             )
 
+    # TODO(1.6): Redefine the scope of the `_boost` and `_boost_discrete`
+    # functions to be the same since SAMME will be the default value for the
+    # "algorithm" parameter in version 1.6. Thus, a distinguishing function is
+    # no longer needed. (Or adjust code here, if another algorithm, shall be
+    # used instead of SAMME.R.)
     def _boost(self, iboost, X, y, sample_weight, random_state):
         """Implement a single boost.
 
@@ -581,6 +596,8 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
         else:  # elif self.algorithm == "SAMME":
             return self._boost_discrete(iboost, X, y, sample_weight, random_state)
 
+    # TODO(1.6): Remove function. The `_boost_real` function won't be used any
+    # longer, because the SAMME.R algorithm will be deprecated in 1.6.
     def _boost_real(self, iboost, X, y, sample_weight, random_state):
         """Implement a single boost using the SAMME.R real algorithm."""
         estimator = self._make_estimator(random_state=random_state)
@@ -761,7 +778,7 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
         -------
         score : ndarray of shape of (n_samples, k)
             The decision function of the input samples. The order of
-            outputs is the same of that of the :term:`classes_` attribute.
+            outputs is the same as that of the :term:`classes_` attribute.
             Binary classification is a special cases with ``k == 1``,
             otherwise ``k==n_classes``. For binary classification,
             values closer to -1 or 1 mean more like the first or second
@@ -773,6 +790,7 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
         n_classes = self.n_classes_
         classes = self.classes_[:, np.newaxis]
 
+        # TODO(1.6): Remove, because "algorithm" param will be deprecated in 1.6
         if self.algorithm == "SAMME.R":
             # The weights are all 1. for SAMME.R
             pred = sum(
@@ -780,7 +798,11 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
             )
         else:  # self.algorithm == "SAMME"
             pred = sum(
-                (estimator.predict(X) == classes).T * w
+                np.where(
+                    (estimator.predict(X) == classes).T,
+                    w,
+                    -1 / (n_classes - 1) * w,
+                )
                 for estimator, w in zip(self.estimators_, self.estimator_weights_)
             )
 
@@ -823,12 +845,17 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
         for weight, estimator in zip(self.estimator_weights_, self.estimators_):
             norm += weight
 
+            # TODO(1.6): Remove, because "algorithm" param will be deprecated in
+            # 1.6
             if self.algorithm == "SAMME.R":
                 # The weights are all 1. for SAMME.R
                 current_pred = _samme_proba(estimator, n_classes, X)
             else:  # elif self.algorithm == "SAMME":
-                current_pred = estimator.predict(X)
-                current_pred = (current_pred == classes).T * weight
+                current_pred = np.where(
+                    (estimator.predict(X) == classes).T,
+                    weight,
+                    -1 / (n_classes - 1) * weight,
+                )
 
             if pred is None:
                 pred = current_pred
@@ -846,7 +873,7 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
     def _compute_proba_from_decision(decision, n_classes):
         """Compute probabilities from the decision function.
 
-        This is based eq. (4) of [1] where:
+        This is based eq. (15) of [1] where:
             p(y=c|X) = exp((1 / K-1) f_c(X)) / sum_k(exp((1 / K-1) f_k(X)))
                      = softmax((1 / K-1) * f(X))
 
@@ -941,7 +968,7 @@ class AdaBoostClassifier(ClassifierMixin, BaseWeightBoosting):
         return np.log(self.predict_proba(X))
 
 
-class AdaBoostRegressor(RegressorMixin, BaseWeightBoosting):
+class AdaBoostRegressor(_RoutingNotSupportedMixin, RegressorMixin, BaseWeightBoosting):
     """An AdaBoost regressor.
 
     An AdaBoost [1] regressor is a meta-estimator that begins by fitting a
@@ -991,16 +1018,6 @@ class AdaBoostRegressor(RegressorMixin, BaseWeightBoosting):
         Pass an int for reproducible output across multiple function calls.
         See :term:`Glossary <random_state>`.
 
-    base_estimator : object, default=None
-        The base estimator from which the boosted ensemble is built.
-        If ``None``, then the base estimator is
-        :class:`~sklearn.tree.DecisionTreeRegressor` initialized with
-        `max_depth=3`.
-
-        .. deprecated:: 1.2
-            `base_estimator` is deprecated and will be removed in 1.4.
-            Use `estimator` instead.
-
     Attributes
     ----------
     estimator_ : estimator
@@ -1009,13 +1026,6 @@ class AdaBoostRegressor(RegressorMixin, BaseWeightBoosting):
         .. versionadded:: 1.2
            `base_estimator_` was renamed to `estimator_`.
 
-    base_estimator_ : estimator
-        The base estimator from which the ensemble is grown.
-
-        .. deprecated:: 1.2
-            `base_estimator_` is deprecated and will be removed in 1.4.
-            Use `estimator_` instead.
-
     estimators_ : list of regressors
         The collection of fitted sub-estimators.
 
@@ -1085,14 +1095,12 @@ class AdaBoostRegressor(RegressorMixin, BaseWeightBoosting):
         learning_rate=1.0,
         loss="linear",
         random_state=None,
-        base_estimator="deprecated",
     ):
         super().__init__(
             estimator=estimator,
             n_estimators=n_estimators,
             learning_rate=learning_rate,
             random_state=random_state,
-            base_estimator=base_estimator,
         )
 
         self.loss = loss
