@@ -4,10 +4,16 @@ from raw data. It currently includes methods to extract features from text and
 images.
 """
 
-from ._dict_vectorizer import DictVectorizer
-from ._hashing import FeatureHasher
-from .image import img_to_graph, grid_to_graph
 from . import text
+from ._dict_vectorizer import DictVectorizer
+from ._hash import FeatureHasher
+from .image import grid_to_graph, img_to_graph
 
-__all__ = ['DictVectorizer', 'image', 'img_to_graph', 'grid_to_graph', 'text',
-           'FeatureHasher']
+__all__ = [
+    "DictVectorizer",
+    "image",
+    "img_to_graph",
+    "grid_to_graph",
+    "text",
+    "FeatureHasher",
+]
