@@ -139,6 +139,16 @@ def contingency_matrix(
         otherwise with the ``dtype`` argument. If ``eps`` is given, the dtype
         will be float.
         Will be a ``sklearn.sparse.csr_matrix`` if ``sparse=True``.
+
+    Examples
+    --------
+    >>> from sklearn.metrics.cluster import contingency_matrix
+    >>> labels_true = [0, 0, 1, 1, 2, 2]
+    >>> labels_pred = [1, 0, 2, 1, 0, 2]
+    >>> contingency_matrix(labels_true, labels_pred)
+    array([[1, 1, 0],
+           [0, 1, 1],
+           [1, 0, 1]])
     """
 
     if eps is not None and sparse:
@@ -207,9 +217,9 @@ def pair_confusion_matrix(labels_true, labels_pred):
 
     See Also
     --------
-    rand_score: Rand Score.
-    adjusted_rand_score: Adjusted Rand Score.
-    adjusted_mutual_info_score: Adjusted Mutual Information.
+    sklearn.metrics.rand_score : Rand Score.
+    sklearn.metrics.adjusted_rand_score : Adjusted Rand Score.
+    sklearn.metrics.adjusted_mutual_info_score : Adjusted Mutual Information.
 
     References
     ----------
@@ -484,7 +494,7 @@ def homogeneity_completeness_v_measure(labels_true, labels_pred, *, beta=1.0):
         Ground truth class labels to be used as a reference.
 
     labels_pred : array-like of shape (n_samples,)
-        Gluster labels to evaluate.
+        Cluster labels to evaluate.
 
     beta : float, default=1.0
         Ratio of weight attributed to ``homogeneity`` vs ``completeness``.
@@ -508,6 +518,13 @@ def homogeneity_completeness_v_measure(labels_true, labels_pred, *, beta=1.0):
     homogeneity_score : Homogeneity metric of cluster labeling.
     completeness_score : Completeness metric of cluster labeling.
     v_measure_score : V-Measure (NMI with arithmetic mean option).
+
+    Examples
+    --------
+    >>> from sklearn.metrics import homogeneity_completeness_v_measure
+    >>> y_true, y_pred = [0, 0, 1, 1, 2, 2], [0, 0, 1, 2, 2, 2]
+    >>> homogeneity_completeness_v_measure(y_true, y_pred)
+    (0.71..., 0.77..., 0.73...)
     """
     labels_true, labels_pred = check_clusterings(labels_true, labels_pred)
 
@@ -838,9 +855,10 @@ def mutual_info_score(labels_true, labels_pred, *, contingency=None):
 
     contingency : {array-like, sparse matrix} of shape \
             (n_classes_true, n_classes_pred), default=None
-        A contingency matrix given by the :func:`contingency_matrix` function.
-        If value is ``None``, it will be computed, otherwise the given value is
-        used, with ``labels_true`` and ``labels_pred`` ignored.
+        A contingency matrix given by the
+        :func:`~sklearn.metrics.cluster.contingency_matrix` function. If value
+        is ``None``, it will be computed, otherwise the given value is used,
+        with ``labels_true`` and ``labels_pred`` ignored.
 
     Returns
     -------
@@ -856,6 +874,14 @@ def mutual_info_score(labels_true, labels_pred, *, contingency=None):
     Notes
     -----
     The logarithm used is the natural logarithm (base-e).
+
+    Examples
+    --------
+    >>> from sklearn.metrics import mutual_info_score
+    >>> labels_true = [0, 1, 1, 0, 1, 0]
+    >>> labels_pred = [0, 1, 0, 0, 1, 1]
+    >>> mutual_info_score(labels_true, labels_pred)
+    0.056...
     """
     if contingency is None:
         labels_true, labels_pred = check_clusterings(labels_true, labels_pred)
@@ -1020,7 +1046,7 @@ def adjusted_mutual_info_score(
     h_true, h_pred = entropy(labels_true), entropy(labels_pred)
     normalizer = _generalized_average(h_true, h_pred, average_method)
     denominator = normalizer - emi
-    # Avoid 0.0 / 0.0 when expectation equals maximum, i.e a perfect match.
+    # Avoid 0.0 / 0.0 when expectation equals maximum, i.e. a perfect match.
     # normalizer should always be >= emi, but because of floating-point
     # representation, sometimes emi is slightly larger. Correct this
     # by preserving the sign.
@@ -1170,7 +1196,7 @@ def fowlkes_mallows_score(labels_true, labels_pred, *, sparse=False):
     ``labels_pred``), ``FP`` is the number of **False Positive** (i.e. the
     number of pair of points that belongs in the same clusters in
     ``labels_true`` and not in ``labels_pred``) and ``FN`` is the number of
-    **False Negative** (i.e the number of pair of points that belongs in the
+    **False Negative** (i.e. the number of pair of points that belongs in the
     same clusters in ``labels_pred`` and not in ``labels_True``).
 
     The score ranges from 0 to 1. A high value indicates a good similarity
